@@ -1,12 +1,12 @@
 #!/usr/bin/perl
 
-# $Id: asa_sessions.pl 7603 2013-04-11 09:28:27Z joostvb $
+# $Id: asa_sessions.pl 8161 2013-08-12 13:58:07Z hurko $
 # $URL: https://pong.uvt.nl/its-nettel/Netwerken/Procedures/noc-cacti-plugins/script/asa_sessions.pl $
 
 use strict;
 use warnings FATAL => 'all';
 
-use NOC::Net::SNMP; 
+use UvT::NOC::Net::SNMP; 
 
 if ($#ARGV != 0)
 {
@@ -17,6 +17,7 @@ if ($#ARGV != 0)
 
 my $ip = $ARGV[0];
 
+# TODO : snmp community gegevens uit global config halen
 my $snmp_community = "hkbu4kma";
 my $snmp_options   = "-Oqv";
 
@@ -28,4 +29,7 @@ my $ipsec_sessions = getInfoBySNMPv2($ip, $snmp_community, $crasIPSecNumSessions
 my $l2l_sessions   = getInfoBySNMPv2($ip, $snmp_community, $crasL2LNumSessions, $snmp_options);
 my $ssl_sessions   = getInfoBySNMPv2($ip, $snmp_community, $crasSVCNumSessions, $snmp_options);
 
+# print de cacti-output in het door cacti leesbare formaat :
+# ipsec:23 ssl:104 l2l:3
+
 print "ipsec:$ipsec_sessions ssl:$ssl_sessions l2l:$l2l_sessions";
