@@ -165,13 +165,16 @@ sub getAPNamesAndIDs
 
 	foreach my $line (@snmp_result)
 	{
-		my $snmp_line = trim($line);
-		$snmp_line = stringReplace($oid . ".", "", $snmp_line);
+		unless ($line =~ m/No Such Instance currently exists at this OID/)
+		{
+			my $snmp_line = trim($line);
+			$snmp_line = stringReplace($oid . ".", "", $snmp_line);
 
-		my $apID = trim(substr($snmp_line, 0, index($snmp_line, '=')));
-		my $apName = trim(substr($snmp_line, index($snmp_line, '"') + 1, rindex($snmp_line, '"') - index($snmp_line, '"') - 1));
+			my $apID = trim(substr($snmp_line, 0, index($snmp_line, '=')));
+			my $apName = trim(substr($snmp_line, index($snmp_line, '"') + 1, rindex($snmp_line, '"') - index($snmp_line, '"') - 1));
 
-		$apList->addAccessPoint(new UvT::NOC::InfraStructure::AccessPoint(name => $apName, id => $apID));
+			$apList->addAccessPoint(new UvT::NOC::InfraStructure::AccessPoint(name => $apName, id => $apID));
+		}
 	}
 }
 
@@ -193,15 +196,18 @@ sub getAPBaseMacs
 
 	foreach my $line (@snmp_result)
     {
-		my $snmp_line = trim($line);
-		$snmp_line = stringReplace($oid . ".", "", $snmp_line);
+		unless ($line =~ m/No Such Instance currently exists at this OID/)
+		{
+			my $snmp_line = trim($line);
+			$snmp_line = stringReplace($oid . ".", "", $snmp_line);
 
-		my $apID = trim(substr($snmp_line, 0, index($snmp_line, '=')));
-        my $apValue = trim(removeQuotes(trim(substr($snmp_line, rindex($snmp_line, ':') + 1, length($snmp_line) - rindex($snmp_line, ':') - 1))));
+			my $apID = trim(substr($snmp_line, 0, index($snmp_line, '=')));
+		    my $apValue = trim(removeQuotes(trim(substr($snmp_line, rindex($snmp_line, ':') + 1, length($snmp_line) - rindex($snmp_line, ':') - 1))));
 
-		$apList->getAccessPointByID($apID)->{mac} = $apValue;
+			$apList->getAccessPointByID($apID)->{mac} = $apValue;
 
-		# print $snmp_line . "    apID : " . $apID . "   apValue : " . $apValue . "\n"; 
+			# print $snmp_line . "    apID : " . $apID . "   apValue : " . $apValue . "\n";
+		}
 	}
 }
 
@@ -226,10 +232,16 @@ sub getAPClientLoad
 
 	foreach my $line (@snmp_result)
 	{
-		my $snmp_line = trim($line);
-		my $apMACAddress = trim(removeQuotes($snmp_line));
-
-		$apList->getAccessPointByMACAddress($apMACAddress)->{clients} += 1;
+		unless ($line =~ m/No Such Instance currently exists at this OID/)
+		{
+			my $snmp_line = trim($line);
+			my $apMACAddress = trim(removeQuotes($snmp_line));
+			eval
+			{
+				$apList->getAccessPointByMACAddress($apMACAddress)->{clients} += 1;
+			};
+			# if ($@)	{ warn "AP with mac $apMACAddress not found\n"; }
+		}
 	}
 }
 
